@@ -7,6 +7,7 @@ from collections import OrderedDict
 from copy import deepcopy
 from io import IOBase
 from itertools import chain
+from multiprocessing import Pool
 from subprocess import getstatusoutput
 from traceback import format_exception
 from types import TracebackType
@@ -719,7 +720,8 @@ def _get_freeze_source_packages(
 @functools.lru_cache()
 def get_package_requirements(
     package_name: str,
-    recursive: bool = True
+    recursive: bool = True,
+    _parallelize: bool = True
 ) -> List[str]:
     # Get the output of `pip show`
     status: int
@@ -732,31 +734,54 @@ def get_package_requirements(
     package_requirements: List[str] = []
     for line in output.split('\n'):
         if line.startswith('Requires:'):
-            required_package_name: str
-            for required_package_name in line[9:].lstrip().split(','):
-                required_package_name = required_package_name.strip().replace(
-                    '_', '-'
+            requires_package_names: Tuple[str] = tuple(
+                normalized_required_package_name
+                for normalized_required_package_name in (
+                    required_package_name.strip().replace(
+                        '_', '-'
+                    )
+                    for required_package_name in
+                    line[9:].lstrip().split(',')
                 )
-                if required_package_name:
-                    if recursive:
-                        required_package_depencency_name: str
-                        for required_package_depencency_name in (
-                            get_package_requirements(required_package_name)
-                        ):
-                            if required_package_depencency_name not in (
-                                required_package_names
-                            ):
-                                package_requirements.append(
-                                    required_package_depencency_name
-                                )
-                                required_package_names.add(
-                                    required_package_depencency_name
-                                )
+                if normalized_required_package_name
+            )
+            if not requires_package_names:
+                continue
+            required_package_name: str
+            for required_package_name in requires_package_names:
+                if required_package_name not in (
+                    required_package_names
+                ):
+                    package_requirements.append(required_package_name)
+                    required_package_names.add(required_package_name)
+            if recursive:
+                requires_packages_require: Iterable[str]
+                arguments: Iterable[Tuple[str, bool]] = zip(
+                    requires_package_names,
+                    [False] * len(requires_package_names)
+                )
+                if _parallelize:
+                    pool: Pool
+                    with Pool() as pool:
+                        requires_packages_require = chain(*pool.starmap(
+                            get_package_requirements,
+                            arguments
+                        ))
+                else:
+                    requires_packages_require = chain(*map(
+                        get_package_requirements,
+                        arguments
+                    ))
+                for required_package_name in requires_packages_require:
                     if required_package_name not in (
                         required_package_names
                     ):
-                        package_requirements.append(required_package_name)
-                        required_package_names.add(required_package_name)
+                        package_requirements.append(
+                            required_package_name
+                        )
+                        required_package_names.add(
+                            required_package_name
+                        )
             break
     return package_requirements
 
